Struct four_bar::plot::coord::combinators::WithKeyPointMethod
source · [−]pub struct WithKeyPointMethod<R> where
R: Ranged, { /* private fields */ }plot only.Expand description
The coordinate decorator that allows customized keypoint algorithms. Normally, all the coordinate spec implements its own key point algorith But this decorator allows you override the pre-defined key point algorithm.
To use this decorator, see BindKeyPointMethod::with_key_point_func
Implementations
sourceimpl<R> WithKeyPointMethod<R> where
R: Ranged,
impl<R> WithKeyPointMethod<R> where
R: Ranged,
sourcepub fn with_light_point_func<F>(self, func: F) -> WithKeyPointMethod<R> where
F: 'static + Fn(usize) -> Vec<<R as Ranged>::ValueType, Global>,
pub fn with_light_point_func<F>(self, func: F) -> WithKeyPointMethod<R> where
F: 'static + Fn(usize) -> Vec<<R as Ranged>::ValueType, Global>,
Define the light key point algorithm, by default this returns an empty set