pub struct WithKeyPoints<Inner> where
    Inner: Ranged
{ /* private fields */ }
Available on crate feature plot only.
The coordinate decorator that binds a key point vector. Normally, all the ranged coordinate implements its own keypoint algorithm to determine how to render the tick mark and mesh grid. This decorator allows customized tick mark specifiied by vector. See BindKeyPoints::with_key_points for details. Note: For any coordinate spec wrapped by this decorator, the maxium number of labels configured by MeshStyle will be ignored and the key point function will always returns the entire vector

Implementations

Specify the light key points, which is used to render the light mesh line

Get a reference to the bold points

Get a mut reference to the bold points

Get a reference to light key points

Get a mut reference to the light key points