pub struct BoldPoints(pub usize);Expand description
The key point hint indicates we only need key point for the bold grid lines
Tuple Fields
0: usizeTrait Implementations
sourceimpl KeyPointHint for BoldPoints
impl KeyPointHint for BoldPoints
sourcefn max_num_points(&self) -> usize
fn max_num_points(&self) -> usize
Returns the max number of key points
sourcefn weight(&self) -> KeyPointWeight
fn weight(&self) -> KeyPointWeight
Returns the weight for this hint
sourcefn bold_points(&self) -> usize
fn bold_points(&self) -> usize
Returns the point number constraint for the bold points