Structs
A 3D cartesian coordinate system
The projection matrix which is used to project the 3D space to the 2D display panel
The helper struct to build a projection matrix
A 3D cartesian coordinate system
The projection matrix which is used to project the 3D space to the 2D display panel
The helper struct to build a projection matrix