Available on crate feature
plot only.Expand description
The coordinate translation that only impose shift
Tuple Fields
0: (i32, i32)Trait Implementations
sourceimpl CoordTranslate for Shift
impl CoordTranslate for Shift
sourceimpl ReverseCoordTranslate for Shift
impl ReverseCoordTranslate for Shift
sourcefn reverse_translate(&self, input: (i32, i32)) -> Option<(i32, i32)>
fn reverse_translate(&self, input: (i32, i32)) -> Option<(i32, i32)>
Reverse translate the coordinate from the drawing coordinate to the logic coordinate. Note: the return value is an option, because it’s possible that the drawing coordinate isn’t able to be represented in te guest coordinate system Read more