pub struct BackendCoordOnly;Trait Implementations
sourceimpl CoordMapper for BackendCoordOnly
impl CoordMapper for BackendCoordOnly
sourceimpl<'a, Coord, DB> Drawable<DB, BackendCoordOnly> for BitMapElement<'a, Coord, RGBPixel> where
DB: DrawingBackend,
impl<'a, Coord, DB> Drawable<DB, BackendCoordOnly> for BitMapElement<'a, Coord, RGBPixel> where
DB: DrawingBackend,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB> Drawable<DB, BackendCoordOnly> for Polygon<Coord> where
DB: DrawingBackend,
impl<Coord, DB> Drawable<DB, BackendCoordOnly> for Polygon<Coord> where
DB: DrawingBackend,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB> Drawable<DB, BackendCoordOnly> for PathElement<Coord> where
DB: DrawingBackend,
impl<Coord, DB> Drawable<DB, BackendCoordOnly> for PathElement<Coord> where
DB: DrawingBackend,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB> Drawable<DB, BackendCoordOnly> for Pixel<Coord> where
DB: DrawingBackend,
impl<Coord, DB> Drawable<DB, BackendCoordOnly> for Pixel<Coord> where
DB: DrawingBackend,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<K, DB, O> Drawable<DB, BackendCoordOnly> for Boxplot<K, O> where
DB: DrawingBackend,
O: BoxplotOrient<K, f32>,
impl<K, DB, O> Drawable<DB, BackendCoordOnly> for Boxplot<K, O> where
DB: DrawingBackend,
O: BoxplotOrient<K, f32>,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB, A, B> Drawable<DB, BackendCoordOnly> for ComposedElement<Coord, DB, A, B> where
DB: DrawingBackend,
A: Drawable<DB, BackendCoordOnly>,
B: Drawable<DB, BackendCoordOnly>,
&'a A: for<'a> PointCollection<'a, (i32, i32), BackendCoordOnly>,
&'b B: for<'b> PointCollection<'b, (i32, i32), BackendCoordOnly>,
impl<Coord, DB, A, B> Drawable<DB, BackendCoordOnly> for ComposedElement<Coord, DB, A, B> where
DB: DrawingBackend,
A: Drawable<DB, BackendCoordOnly>,
B: Drawable<DB, BackendCoordOnly>,
&'a A: for<'a> PointCollection<'a, (i32, i32), BackendCoordOnly>,
&'b B: for<'b> PointCollection<'b, (i32, i32), BackendCoordOnly>,
sourcefn draw<I>(
&self,
pos: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
pos: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB, Size> Drawable<DB, BackendCoordOnly> for Circle<Coord, Size> where
DB: DrawingBackend,
Size: SizeDesc,
impl<Coord, DB, Size> Drawable<DB, BackendCoordOnly> for Circle<Coord, Size> where
DB: DrawingBackend,
Size: SizeDesc,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB, Size> Drawable<DB, BackendCoordOnly> for Cross<Coord, Size> where
DB: DrawingBackend,
Size: SizeDesc,
impl<Coord, DB, Size> Drawable<DB, BackendCoordOnly> for Cross<Coord, Size> where
DB: DrawingBackend,
Size: SizeDesc,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB> Drawable<DB, BackendCoordOnly> for EmptyElement<Coord, DB> where
DB: DrawingBackend,
impl<Coord, DB> Drawable<DB, BackendCoordOnly> for EmptyElement<Coord, DB> where
DB: DrawingBackend,
sourcefn draw<I>(
&self,
_pos: I,
_backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
_pos: I,
_backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<X, Y, DB> Drawable<DB, BackendCoordOnly> for CandleStick<X, Y> where
Y: PartialOrd<Y>,
DB: DrawingBackend,
impl<X, Y, DB> Drawable<DB, BackendCoordOnly> for CandleStick<X, Y> where
Y: PartialOrd<Y>,
DB: DrawingBackend,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB, Size> Drawable<DB, BackendCoordOnly> for TriangleMarker<Coord, Size> where
DB: DrawingBackend,
Size: SizeDesc,
impl<Coord, DB, Size> Drawable<DB, BackendCoordOnly> for TriangleMarker<Coord, Size> where
DB: DrawingBackend,
Size: SizeDesc,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
ps: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<'a, DB, Coord> Drawable<DB, BackendCoordOnly> for DynElement<'a, DB, Coord> where
DB: DrawingBackend,
Coord: Clone,
impl<'a, DB, Coord> Drawable<DB, BackendCoordOnly> for DynElement<'a, DB, Coord> where
DB: DrawingBackend,
Coord: Clone,
sourcefn draw<I>(
&self,
pos: I,
backend: &mut DB,
parent_dim: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
pos: I,
backend: &mut DB,
parent_dim: (u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<K, V, O, DB> Drawable<DB, BackendCoordOnly> for ErrorBar<K, V, O> where
O: ErrorBarOrient<K, V>,
DB: DrawingBackend,
impl<K, V, O, DB> Drawable<DB, BackendCoordOnly> for ErrorBar<K, V, O> where
O: ErrorBarOrient<K, V>,
DB: DrawingBackend,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<'a, Coord, DB, T> Drawable<DB, BackendCoordOnly> for Text<'a, Coord, T> where
Coord: 'a,
DB: DrawingBackend,
T: Borrow<str>,
impl<'a, Coord, DB, T> Drawable<DB, BackendCoordOnly> for Text<'a, Coord, T> where
Coord: 'a,
DB: DrawingBackend,
T: Borrow<str>,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<Coord, DB> Drawable<DB, BackendCoordOnly> for Rectangle<Coord> where
DB: DrawingBackend,
impl<Coord, DB> Drawable<DB, BackendCoordOnly> for Rectangle<Coord> where
DB: DrawingBackend,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<'a, Coord, DB, T> Drawable<DB, BackendCoordOnly> for MultiLineText<'a, Coord, T> where
Coord: 'a,
DB: DrawingBackend,
T: Borrow<str>,
impl<'a, Coord, DB, T> Drawable<DB, BackendCoordOnly> for MultiLineText<'a, Coord, T> where
Coord: 'a,
DB: DrawingBackend,
T: Borrow<str>,
sourcefn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
fn draw<I>(
&self,
points: I,
backend: &mut DB,
(u32, u32)
) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>> where
I: Iterator<Item = (i32, i32)>,
Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly Read more
sourceimpl<'a, K, O> PointCollection<'a, (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType), BackendCoordOnly> for &'a Boxplot<K, O> where
K: Clone,
O: BoxplotOrient<K, f32>,
impl<'a, K, O> PointCollection<'a, (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType), BackendCoordOnly> for &'a Boxplot<K, O> where
K: Clone,
O: BoxplotOrient<K, f32>,
type Point = (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType)
type Point = (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType)
The item in point iterator
type IntoIter = Vec<<&'a Boxplot<K, O> as PointCollection<'a, (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType), BackendCoordOnly>>::Point, Global>
type IntoIter = Vec<<&'a Boxplot<K, O> as PointCollection<'a, (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType), BackendCoordOnly>>::Point, Global>
The point iterator
sourcefn point_iter(
self
) -> <&'a Boxplot<K, O> as PointCollection<'a, (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType), BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a Boxplot<K, O> as PointCollection<'a, (<O as BoxplotOrient<K, f32>>::XType, <O as BoxplotOrient<K, f32>>::YType), BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'a, K, V, O> PointCollection<'a, (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType), BackendCoordOnly> for &'a ErrorBar<K, V, O> where
K: Clone,
V: Clone,
O: ErrorBarOrient<K, V>,
impl<'a, K, V, O> PointCollection<'a, (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType), BackendCoordOnly> for &'a ErrorBar<K, V, O> where
K: Clone,
V: Clone,
O: ErrorBarOrient<K, V>,
type Point = (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType)
type Point = (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType)
The item in point iterator
type IntoIter = Vec<<&'a ErrorBar<K, V, O> as PointCollection<'a, (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType), BackendCoordOnly>>::Point, Global>
type IntoIter = Vec<<&'a ErrorBar<K, V, O> as PointCollection<'a, (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType), BackendCoordOnly>>::Point, Global>
The point iterator
sourcefn point_iter(
self
) -> <&'a ErrorBar<K, V, O> as PointCollection<'a, (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType), BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a ErrorBar<K, V, O> as PointCollection<'a, (<O as ErrorBarOrient<K, V>>::XType, <O as ErrorBarOrient<K, V>>::YType), BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'a, X, Y> PointCollection<'a, (X, Y), BackendCoordOnly> for &'a CandleStick<X, Y> where
X: 'a,
Y: 'a + PartialOrd<Y>,
impl<'a, X, Y> PointCollection<'a, (X, Y), BackendCoordOnly> for &'a CandleStick<X, Y> where
X: 'a,
Y: 'a + PartialOrd<Y>,
sourceimpl<'a, 'b, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a BitMapElement<'b, Coord, RGBPixel>
impl<'a, 'b, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a BitMapElement<'b, Coord, RGBPixel>
sourcefn point_iter(
self
) -> <&'a BitMapElement<'b, Coord, RGBPixel> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a BitMapElement<'b, Coord, RGBPixel> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'a, Coord, Size> PointCollection<'a, Coord, BackendCoordOnly> for &'a Cross<Coord, Size> where
Coord: 'a,
Size: SizeDesc,
impl<'a, Coord, Size> PointCollection<'a, Coord, BackendCoordOnly> for &'a Cross<Coord, Size> where
Coord: 'a,
Size: SizeDesc,
sourceimpl<'a, Coord, Size> PointCollection<'a, Coord, BackendCoordOnly> for &'a Circle<Coord, Size> where
Size: SizeDesc,
impl<'a, Coord, Size> PointCollection<'a, Coord, BackendCoordOnly> for &'a Circle<Coord, Size> where
Size: SizeDesc,
sourceimpl<'b, 'a, Coord, T> PointCollection<'a, Coord, BackendCoordOnly> for &'a MultiLineText<'b, Coord, T> where
Coord: 'a,
T: 'a + Borrow<str>,
impl<'b, 'a, Coord, T> PointCollection<'a, Coord, BackendCoordOnly> for &'a MultiLineText<'b, Coord, T> where
Coord: 'a,
T: 'a + Borrow<str>,
sourcefn point_iter(
self
) -> <&'a MultiLineText<'b, Coord, T> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a MultiLineText<'b, Coord, T> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a PathElement<Coord>
impl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a PathElement<Coord>
sourceimpl<'a, Coord, DB> PointCollection<'a, Coord, BackendCoordOnly> for &'a EmptyElement<Coord, DB> where
DB: DrawingBackend,
impl<'a, Coord, DB> PointCollection<'a, Coord, BackendCoordOnly> for &'a EmptyElement<Coord, DB> where
DB: DrawingBackend,
sourcefn point_iter(
self
) -> <&'a EmptyElement<Coord, DB> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a EmptyElement<Coord, DB> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a Pixel<Coord>
impl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a Pixel<Coord>
sourcefn point_iter(
self
) -> <&'a Pixel<Coord> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a Pixel<Coord> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'a, 'b, DB, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a DynElement<'b, DB, Coord> where
'b: 'a,
DB: DrawingBackend,
Coord: Clone,
impl<'a, 'b, DB, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a DynElement<'b, DB, Coord> where
'b: 'a,
DB: DrawingBackend,
Coord: Clone,
sourcefn point_iter(
self
) -> <&'a DynElement<'b, DB, Coord> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a DynElement<'b, DB, Coord> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'a, Coord, Size> PointCollection<'a, Coord, BackendCoordOnly> for &'a TriangleMarker<Coord, Size> where
Coord: 'a,
Size: SizeDesc,
impl<'a, Coord, Size> PointCollection<'a, Coord, BackendCoordOnly> for &'a TriangleMarker<Coord, Size> where
Coord: 'a,
Size: SizeDesc,
sourceimpl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a Polygon<Coord>
impl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a Polygon<Coord>
sourceimpl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a Rectangle<Coord>
impl<'a, Coord> PointCollection<'a, Coord, BackendCoordOnly> for &'a Rectangle<Coord>
sourceimpl<'b, 'a, Coord, T> PointCollection<'a, Coord, BackendCoordOnly> for &'a Text<'b, Coord, T> where
Coord: 'a,
T: 'a + Borrow<str>,
impl<'b, 'a, Coord, T> PointCollection<'a, Coord, BackendCoordOnly> for &'a Text<'b, Coord, T> where
Coord: 'a,
T: 'a + Borrow<str>,
sourcefn point_iter(
self
) -> <&'a Text<'b, Coord, T> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'a Text<'b, Coord, T> as PointCollection<'a, Coord, BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping
sourceimpl<'b, Coord, DB, A, B> PointCollection<'b, Coord, BackendCoordOnly> for &'b ComposedElement<Coord, DB, A, B> where
DB: DrawingBackend,
A: Drawable<DB, BackendCoordOnly>,
B: Drawable<DB, BackendCoordOnly>,
impl<'b, Coord, DB, A, B> PointCollection<'b, Coord, BackendCoordOnly> for &'b ComposedElement<Coord, DB, A, B> where
DB: DrawingBackend,
A: Drawable<DB, BackendCoordOnly>,
B: Drawable<DB, BackendCoordOnly>,
sourcefn point_iter(
self
) -> <&'b ComposedElement<Coord, DB, A, B> as PointCollection<'b, Coord, BackendCoordOnly>>::IntoIter
fn point_iter(
self
) -> <&'b ComposedElement<Coord, DB, A, B> as PointCollection<'b, Coord, BackendCoordOnly>>::IntoIter
framework to do the coordinate mapping