pub trait Drawable<DB, CM = BackendCoordOnly> where
    DB: DrawingBackend,
    CM: CoordMapper
{ fn draw<I>(
        &self,
        pos: I,
        backend: &mut DB,
        parent_dim: (u32, u32)
    ) -> Result<(), DrawingErrorKind<<DB as DrawingBackend>::ErrorType>>
    where
        I: Iterator<Item = <CM as CoordMapper>::Output>
; }
Available on crate feature plot only.
The trait indicates we are able to draw it on a drawing area

Required Methods

Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly

Implementors