Available on crate feature
plot only.Expand description
The functions used to plot the 3D curve and synthesis result.
Re-exports
pub use super::*;
Functions
- Get the area of a set of points in 3D.
- Check the point is in front of the sphere.
Type Aliases
- Drawing option of spherical four-bar linkage and its input angle.