plot only.Expand description
The style for shapes and text, font, color, etc.
Modules
Basic predefined colors.
Text anchor attributes are used to properly position the text.
Structs
Describes a font
The color described by HSL color space
The palette of 99% accessibility
The palette of 100% accessibility
The palette of 99.99% accessibility
A color in the given palette
The RGBA representation of the color, Plotters use RGBA as the internal representation of color
The color described by its RGB value
Style for any of shape
Style of a text
Enums
Describes font family. This can be either a specific font family name, such as “arial”, or a general font family class, such as “serif” and “sans-serif”
Describes the font style. Such as Italic, Oblique, etc.
Specifying text transformations
Describes a relative size, might be 1. portion of height 2. portion of width 3. portion of the minimal of height and weight
Constants
The predefined black color
The predefined blue color
The predefined cyan color
The predefined green color
The predefined magenta color
The predefined red color
The predefined transparent
The predefined white color
The predefined yellow color
Traits
Allows a value turns into a relative size
Any color representation
The trait that allows some type turns into a font description
The trait that describes a size, it may be a relative size which the size is determined by the parent size, e.g., 10% of the parent width
Type Definitions
The error type for the font implementation
The type we used to represent a result of any font operations