pub enum RelativeSize {
    Height(f64),
    Width(f64),
    Smaller(f64),
}
Available on crate feature plot only.
Describes a relative size, might be 1. portion of height 2. portion of width 3. portion of the minimal of height and weight

Variants

Height(f64)

Percentage height

Width(f64)

Percentage width

Smaller(f64)

Percentage of either height or width, which is smaller

Implementations

Set the lower bound of the relative size.

  • min_sz: The minimal size the relative size can be in pixels
  • returns: The relative size with the bound

Set the upper bound of the relative size

  • max_size: The maximum size in pixels for this relative size
  • returns The relative size with the upper bound