pub trait AsRelative: Into<f64> {
    fn percent_width(self) -> RelativeSize { ... }
    fn percent_height(self) -> RelativeSize { ... }
    fn percent(self) -> RelativeSize { ... }
}
Available on crate feature plot only.
Allows a value turns into a relative size

Provided Methods

Make the value a relative size of percentage of width

Make the value a relative size of percentage of height

Make the value a relative size of percentage of minimal of height and width

Implementors