The functions used to plot the curve and synthesis result.
Modules
The high-level plotting abstractions.
One of the key features of Plotters is flexible coordinate system abstraction and this module provides all the abstraction used for the coordinate abstarction of Plotters.
The data processing module, which implements algorithms related to visualization of data. Such as, down-sampling, etc.
The drawing utils for Plotters. In Plotters, we have two set of drawing APIs: low-level API and high-level API.
Defines the drawing elements, the high-level drawing unit in Plotters drawing system
The module imports the most commonly used types and modules in Plotters
This module contains predefined types of series.
The series in Plotters is actually an iterator of elements, which
can be taken by ChartContext::draw_series function.
The style for shapes and text, font, color, etc.
Functions
Get the bounding box of the data, ignore the labels.
Plot 2D curve.
Plot the synthesis history.