Struct four_bar::plot::coord::combinators::WithKeyPoints
source · [−]pub struct WithKeyPoints<Inner> where
Inner: Ranged, { /* private fields */ }plot only.Expand description
The coordinate decorator that binds a key point vector. Normally, all the ranged coordinate implements its own keypoint algorithm to determine how to render the tick mark and mesh grid. This decorator allows customized tick mark specifiied by vector. See BindKeyPoints::with_key_points for details. Note: For any coordinate spec wrapped by this decorator, the maxium number of labels configured by MeshStyle will be ignored and the key point function will always returns the entire vector
Implementations
sourceimpl<I> WithKeyPoints<I> where
I: Ranged,
impl<I> WithKeyPoints<I> where
I: Ranged,
sourcepub fn with_light_points<T>(self, iter: T) -> WithKeyPoints<I> where
T: IntoIterator<Item = <I as Ranged>::ValueType>,
pub fn with_light_points<T>(self, iter: T) -> WithKeyPoints<I> where
T: IntoIterator<Item = <I as Ranged>::ValueType>,
Specify the light key points, which is used to render the light mesh line
sourcepub fn bold_points(&self) -> &[<I as Ranged>::ValueType]
pub fn bold_points(&self) -> &[<I as Ranged>::ValueType]
Get a reference to the bold points
sourcepub fn bold_points_mut(&mut self) -> &mut [<I as Ranged>::ValueType]
pub fn bold_points_mut(&mut self) -> &mut [<I as Ranged>::ValueType]
Get a mut reference to the bold points
sourcepub fn light_points(&self) -> &[<I as Ranged>::ValueType]
pub fn light_points(&self) -> &[<I as Ranged>::ValueType]
Get a reference to light key points
sourcepub fn light_points_mut(&mut self) -> &mut [<I as Ranged>::ValueType]
pub fn light_points_mut(&mut self) -> &mut [<I as Ranged>::ValueType]
Get a mut reference to the light key points